@@ -12,6 +12,7 @@ import six
 from nose2 import config
 
 log = logging.getLogger(__name__)
+__unittest = True
 
 # FIXME decide on a real rule for camelCase vs under_score and stick with it.
 
@@ -156,7 +157,7 @@ class Plugin(six.with_metaclass(PluginMeta)):
                 if six.callable(callback):
                     callback(values)
                 elif isinstance(callback, list):
-                    callback.append(values)
+                    callback.extend(values)
                 else:
                     raise ValueError("Invalid callback %s for plugin option %s",
                                      callback, option_string)
@@ -242,7 +243,7 @@ class PluginInterface(object):
         'reportSuccess', 'reportExpectedFailure', 'reportUnexpectedSuccess',
         'reportOtherOutcome', 'outcomeDetail', 'beforeErrorList',
         'beforeSummaryReport', 'afterSummaryReport', 'beforeInteraction',
-        'afterInteraction', 'createTests',
+        'afterInteraction', 'createTests', 'afterTestRun',
         # ... etc?
         )
     hookClass = Hook
@@ -292,7 +293,7 @@ class Event(object):
 
     """
     _attrs = ('handled',)
-    version = '0.1'
+    version = '0.2'
 
     def __init__(self, **metadata):
         self.handled = False
@@ -366,7 +367,9 @@ class StartTestRunEvent(Event):
 
     .. attribute :: suite
 
-       Top-level test suite to execute
+       Top-level test suite to execute. Plugins can filter this suite,
+       or set event.suite to change which tests execute (or how they
+       execute).
 
     .. attribute :: result
 
