@@ -28,6 +28,7 @@ except ImportError:
 import six
 
 
+__unittest = True
 IDENT_RE = re.compile(r'^[_a-zA-Z]\w*$', re.UNICODE)
 VALID_MODULE_RE = re.compile(r'[_a-zA-Z]\w*\.py$', re.UNICODE)
 
@@ -91,10 +92,7 @@ def test_from_name(name, module):
             pass
         else:
             name = real_name
-    try:
-        parent, obj = object_from_name(name, module)
-    except (AttributeError, ImportError):
-        return None
+    parent, obj = object_from_name(name, module)
     return parent, obj, name, index
 
 
@@ -160,6 +158,8 @@ def safe_decode(string):
         return string
     try:
         return string.decode()
+    except AttributeError:
+        return string
     except UnicodeDecodeError:
         pass
     try:
@@ -193,6 +193,24 @@ def format_traceback(test, err):
     return ''.join(msgLines)
 
 
+def transplant_class(cls, module):
+    """Make class appear to reside in ``module``.
+
+    :param cls: A class
+    :param module: A module name
+    :returns: A subclass of ``cls`` that appears to have been defined in ``module``. 
+
+    The returned class's ``__name__`` will be equal to
+    ``cls.__name__``, and its ``__module__`` equal to ``module``.
+
+    """
+    class C(cls):
+        pass
+    C.__module__ = module
+    C.__name__ = cls.__name__
+    return C
+
+
 def parse_log_level(lvl):
     """Return numeric log level given a string"""
     try:
